@@ -1,28 +1,25 @@
 """
 Tests for `tqdm.contrib.itertools`.
 """
-import itertools
+import itertools as it
 
 from tqdm.contrib.itertools import product
 
 from .tests_tqdm import StringIO, closing
 
 
-class NoLenIter(object):
+class NoLenIter:
     def __init__(self, iterable):
         self._it = iterable
 
     def __iter__(self):
-        for i in self._it:
-            yield i
+        yield from self._it
 
 
 def test_product():
     """Test contrib.itertools.product"""
     with closing(StringIO()) as our_file:
         a = range(9)
-        assert list(product(a, a[::-1], file=our_file)) == \
-            list(itertools.product(a, a[::-1]))
+        assert list(product(a, a[::-1], file=our_file)) == list(it.product(a, a[::-1]))
 
-        assert list(product(a, NoLenIter(a), file=our_file)) == \
-            list(itertools.product(a, NoLenIter(a)))
+        assert list(product(a, NoLenIter(a), file=our_file)) == list(it.product(a, NoLenIter(a)))
